#  Copyright (C) 2026
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
from .init_logs import LogsConfig, CustomFormatter, init_logs
from .init_random import init_random
from .parse_args import Arg, parse_args
from .parse_args_as_dataclass import parse_args_as_dataclass
from .parse_args_as_dataclass_or_exit import parse_args_as_dataclass_or_exit
from .parse_args_as_file_with_kwargs import parse_args_as_file_with_kwargs
from .read_file_as_dict import read_file_as_dict, read_config
